#
# spec file for package zfs
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zfs
Version:        0.8.0~rc3
Release:        3.1
%define rver	0.8.0-rc3
Summary:        The ZFS filesystem and utilities
License:        CDDL-1.0 AND GPL-2.0-or-later
Group:          System/Filesystems
Url:            http://zfsonlinux.org/

#Github-URL:	http://github.com/zfsonlinux/zfs
#Git-Clone:	git://github.com/zfsonlinux/zfs
Source:         https://github.com/zfsonlinux/zfs/releases/download/zfs-%rver/zfs-%rver.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  kernel-devel
BuildRequires:  kernel-syms
BuildRequires:  libattr-devel
BuildRequires:  libelf-devel
BuildRequires:  libtirpc-devel
BuildRequires:  modutils
BuildRequires:  pkg-config
BuildRequires:  python
BuildRequires:  sudo
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(blkid)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(zlib)
# Files collide, but zypper does not recognize that (bnc#673720)
Conflicts:      zfs-fuse

%define services zfs-import-cache.service zfs-import-scan.service zfs-mount.service zfs-share.service zfs-zed.service zfs.target zfs-import.target
%kernel_module_package -n zfs -p %name-preamble -x xen

%description
ZFS is a combined file system and logical volume manager designed by
Sun Microsystems. The features of ZFS include protection against data
corruption, support for high storage capacities, integration of the
concepts of filesystem and volume management, snapshots and
copy-on-write clones, continuous integrity checking and automatic
repair, RAID-Z and native NFSv4 ACLs.

ZFS on Linux, which is also known as ZoL, includes fully functional
and stable SPA, DMU, ZVOL, and ZPL layers.

%package -n libnvpair1
Summary:        A tools library for manipulating <name, value> pairs
License:        CDDL-1.0
Group:          System/Libraries

%description -n libnvpair1
ZFS is an advanced file system and volume manager which was
originally developed by Sun Microsystems.

The nvpair library provides routines packing an unpacking nv pairs
for transporting data across process boundaries, transporting between
kernel and userland, and possibly saving onto disk files.

%package -n libuutil1
Summary:        ZFS utility library
License:        CDDL-1.0
Group:          System/Libraries

%description -n libuutil1
ZFS is an advanced file system and volume manager which was
originally developed by Sun Microsystems.

The uutil library contains various utility and wrapper functions used
by the ZFS userland.

%package -n libzfs2
Summary:        ZFS filesystem access library
License:        CDDL-1.0
Group:          System/Libraries

%description -n libzfs2
ZFS is an advanced file system and volume manager which was
originally developed by Sun Microsystems.

%package -n libzfs_core1
Summary:        ZFS filesystem access library
License:        CDDL-1.0
Group:          System/Libraries

%description -n libzfs_core1
libzfs_core is intended to replace libzfs, and has the following
characteristics:
Thread safety, committed interface (stable API), programmatic
error handling and clear atomicity.

%package -n libzpool2
Summary:        Zpool interface
License:        CDDL-1.0
Group:          System/Libraries

%description -n libzpool2
ZFS is an advanced file system and volume manager which was
originally developed by Sun Microsystems.

The zpool library contains
- Emulation of kernel services in userland
- Routines needed by more than one client of libzpool

%package sudo
Summary:        Sudo configuration for the ZFS userspace utilities
License:        CDDL-1.0
Group:          System/Management
Requires:       %{name} = %{version}
Supplements:    packageand(zfs:sudo)
BuildArch:      noarch

%description sudo
zfs-sudo includes sudoers configuration files to allow for easier
delegation of ZFS administrative tasks to unprivileged users (at a finer
level of granularity than giving full root access).

%package devel
Summary:        Development files for the ZFS userspace utilities
License:        CDDL-1.0
Group:          Development/Libraries/C and C++
Requires:       libnvpair1 = %version
Requires:       libuutil1 = %version
Requires:       libzfs2 = %version
Requires:       libzpool2 = %version

%description devel
ZFS is a combined file system and logical volume manager designed by
Sun Microsystems. The features of ZFS include protection against data
corruption, support for high storage capacities, integration of the
concepts of filesystem and volume management, snapshots and
copy-on-write clones, continuous integrity checking and automatic
repair, RAID-Z and native NFSv4 ACLs.

This subpackage contains the development header files and libraries.
needed for compilation of third-party programs.

%prep
%setup -qn zfs-0.8.0

%build
%if 0%{?suse_version} > 1500
export CFLAGS="%{optflags} -I/usr/include/rpc"
sed -e "s|#include <tirpc/rpc/xdr\.h>|#include_next <rpc/xdr.h>|" \
    -i lib/libspl/include/rpc/xdr.h
%endif
for flavor in %flavors_to_build; do
	rm -Rf "../obj-$flavor"
	cp -a . "../obj-$flavor"
	pushd "../obj-$flavor/"
	%configure --with-config=kernel --with-linux="/usr/src/linux" \
		--with-linux-obj="/usr/src/linux-obj/%_target_cpu/$flavor" \
		--sbindir="%_sbindir" ||
		{ cat config.log; exit 1; }
	make %{?_smp_mflags} V=1
	popd
done
%configure --with-config=user \
	--disable-sysvinit \
	--enable-systemd \
	--disable-static
make %{?_smp_mflags} V=1

%install
b="%buildroot"
for flavor in %flavors_to_build; do
	pushd "../obj-$flavor/"
	%make_install
	popd
done
%make_install
rm -f "$b/%_libdir"/*.la
rm -Rf "$b/usr/src"
# all dracut
rm -Rf "$b/%_datadir/initramfs-tools"
rm -Rf "$b/%_datadir/zfs/zfs-tests"
mkdir -p "$b/%_sbindir"
for s in %services; do
	ln -s service "$b/%_sbindir/rc${s%.service}"
done
# udev location different for SLES 15 and later
if [ -d "$b/lib/udev" ] ; then
        mv "$b/lib/udev" "$b/usr/lib/udev/"
fi

%fdupes %buildroot/%_prefix

%pre
%service_add_pre %services

%post
%service_add_post %services

%preun
%service_del_preun %services

%postun
%service_del_postun %services

%post   -n libnvpair1 -p /sbin/ldconfig
%postun -n libnvpair1 -p /sbin/ldconfig
%post   -n libuutil1 -p /sbin/ldconfig
%postun -n libuutil1 -p /sbin/ldconfig
%post   -n libzfs2 -p /sbin/ldconfig
%postun -n libzfs2 -p /sbin/ldconfig
%post   -n libzfs_core1 -p /sbin/ldconfig
%postun -n libzfs_core1 -p /sbin/ldconfig
%post   -n libzpool2 -p /sbin/ldconfig
%postun -n libzpool2 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %_sysconfdir/zfs
%dir %_sysconfdir/zfs/zed.d
%dir %_sysconfdir/zfs/zpool.d
%config %_sysconfdir/zfs/*.example
%config %_sysconfdir/zfs/zed.d/*.sh
%config(noreplace) %_sysconfdir/zfs/zed.d/zed.rc
%config %_sysconfdir/zfs/zpool.d/*
%_bindir/arcstat
%_bindir/arc_summary
%_bindir/dbufstat
%_bindir/raidz_test
%_bindir/z*
%_sbindir/fsck.zfs
%_sbindir/rc*
%_sbindir/z*
%_mandir/man?/*.*
%_datadir/zfs/
/sbin/mount.zfs
%_prefix/lib/dracut/
%_prefix/lib/udev/
%_libexecdir/zfs/
%_unitdir/zfs*
%_presetdir/50-zfs.preset
/usr/lib/modules-load.d/
/usr/lib/systemd/

%files -n libnvpair1
%defattr(-,root,root)
%_libdir/libnvpair.so.1*

%files -n libuutil1
%defattr(-,root,root)
%_libdir/libuutil.so.1*

%files -n libzfs2
%defattr(-,root,root)
%_libdir/libzfs.so.2*

%files -n libzfs_core1
%defattr(-,root,root)
%_libdir/libzfs_core.so.1*

%files -n libzpool2
%defattr(-,root,root)
%_libdir/libzpool.so.2*

%files devel
%defattr(-,root,root)
%_includedir/libspl/
%_includedir/libzfs/
%_libdir/libnvpair.so
%_libdir/libuutil.so
%_libdir/libzfs.so
%_libdir/libzfs_core.so
%_libdir/libzpool.so
%_datadir/pkgconfig/*.pc

%files sudo
%defattr(-,root,root)
%config %_sysconfdir/sudoers.d/zfs

%changelog
* Wed Jan 16 2019 jengelh@inai.de
- Update to new upstream release 0.8.0~rc3
  * New feature: Pool initialization
  * Linux 4.20 support
* Mon Nov 26 2018 jengelh@inai.de
- Update to new upstream release 0.8.0~rc2
  * New feature: Deferred resilvers
  * Compatible with 4.19 Linux kernels.
* Sun Nov 11 2018 brassh@web.de
- bugfixes:
  * remove dependency on spl-kmp-default, since
  SPL has been merged into ZFS
  * fix udev related build error under SLE15 and up
* Sun Sep  9 2018 jengelh@inai.de
- SPL was merged into the ZFS release tarball
- Update to new upstream release 0.8.0~rc1
  * Support for Linux 4.18
  * New features: encryption, device removal, allocation classes,
    pool checkpoints, sequential scrub and resilver, project quota,
    channel programs, Direct I/O
* Fri May 11 2018 kamikazow@pensuse.org
- Update to new upstream release 0.7.9
  * Remove DEBUG_STACKFLAGS to bypass compiler error
  * Fedora 28: Add BuildRequires: libtirpc-devel #7494 #7495
  * RHEL 7.5 compat: FMODE_KABI_ITERATE #7460 #7463
  * Add back iostat -y or -w descriptions #7479 #7483
  * Add test with two kinds of file creation orders #7411
  * Allow mounting datasets more than once #5796 #7207
  * Fix zfs_arc_max minimum tuning #7417
  * Linux compat 4.16: blk_queue_flag_{set,clear} #7428 #7431 #7410
  * Fix 'zfs send/recv' hang with 16M blocks #7365 #7404
  * Clean up (k)shlib and cfg file shebangs
  * Fix "file is executable, but no shebang" warnings #7359 #7395
  * Exclude python scripts from RPM shebang check #7360 #7399
  * Update mmp_delay on sync or skipped, failed write #7330
  * Fedora 28: Fix misc bounds check compiler warnings #7361 #7368
  * Fix hung z_zvol tasks during 'zfs receive' #6330 #6890 #7343
  * Add support for nvme based devids #7356
  * chmod -x on etc/init.d/zfs-*.in automake files #7355 #7327
  * Fix mmap / libaio deadlock #7335 #7339
  * Remove libattr requirement #7344 #7351
  * Fedora 28: Fix "Macro %%_dracutdir has empty body" #7326 #7328
  * modprobe zfs during dracut mount #7322
  * Add support for nvme disk detection #7304
  * Report pool suspended due to MMP #7296
  * Add zfs_scan_ignore_errors tunable #7293
  * Allow to limit zed's syslog chattiness #6886 #7260
  * Record skipped MMP writes in multihost_history #7212
  * Introduce a destroy_dataset helper #7224 #7246 #7249 #7267
* Tue Apr 10 2018 kamikazow@opensuse.org
- Update to new upstream release 0.7.8
  * Compatible with 2.6.32 - 4.16 Linux kernels.
  * Fix: Unlistable and disappearing files #7401
  * Revert "Handle zap_add() failures in mixed ... " #7416
* Thu Mar 22 2018 jengelh@inai.de
- Add rc* convenience commands
- Mark zed.rc as %%config(noreplace)
* Thu Mar 22 2018 mrueckert@suse.de
- we only use systemd macros anyway ... remove the sysvinit scripts
  from the filelist
- force systemd in the configure cmdline for the userspace tools
- force verbose compiler calls
* Tue Mar 20 2018 kamikazow@opensuse.org
- Update to new upstream release 0.7.7
  * Compatible with 2.6.32 - 4.16 Linux kernels.
* Sat Mar 10 2018 kamikazow@opensuse.org
- Ported TW fix by Paolo Panto (munix9)
  * added libtirpc dependency, fixed Tumbleweed build with moved tirpc
* Tue Feb  6 2018 kamikazow@opensuse.org
- Update to new upstream release 0.7.6
  * Compatible with 2.6.32 - 4.15 Linux kernels.
* Tue Dec 19 2017 kamikazow@opensuse.org
- Update to new upstream release 0.7.5
- New systemd target
* Sun Dec 10 2017 kamikazow@opensuse.org
- Update to new upstream release 0.7.3
  * Compatible with 2.6.32 - 4.14 Linux kernels.
- Leap 15 and TW Dec.'17 compatibility thanks to Lorenz Hüdepohl.
* Mon Aug  7 2017 asarai@suse.com
- Update to new upstream release 0.7.0
  * Compatible with 2.6.32 - 4.12 Linux kernels.
* Mon Jul 10 2017 yury.buldakov@gmail.com
- Update to new upstream version 0.6.5.10
  * Compatible with 2.6.32 - 4.12-rc3 Linux kernels.
* Wed Oct 19 2016 jengelh@inai.de
- Update to new upstream release 0.6.5.8
  * Compatible with 2.6.32 - 4.8 Linux kernels.
* Mon Jun  6 2016 dev@stellardeath.org
- Update to new upstream release 0.6.5.7
  * Compatible with 2.6.32 - 4.6 Linux kernels.
  * Fix SPL build failure on PowerPC zfsonlinux/spl#516
  * Fix user namespaces uid/gid mapping zfsonlinux/zfs#4177
  * Fix ZPL miswrite of default POSIX ACL zfsonlinux/zfs#4520
  * Linux 4.5 and 4.6 compatibility zfsonlinux/zfs#4537 zfsonlinux/zfs#4489
  * Ensure /dev/disk/by-partlabel gets correctly populated zfsonlinux/zfs#4517
  * Utilities now work reliably with newly created partitions zfsonlinux/zfs#3708
  * Import now reliably uses device names stored in label zfsonlinux/zfs#3043
  * Fix possible deadlock in zfs_secpolicy_write_perms ioctl zfsonlinux/zfs#4554
  * Fix inverted logic on none elevator comparison zfsonlinux/zfs#4507
  * Add 32 bit FS_IOC32_{GET|SET}FLAGS compat ioctls for PPC zfsonlinux/zfs#4477
* Thu May  5 2016 jengelh@inai.de
- Update to new upstream release 0.6.5.6
  * Add support for s390{,x}
  * Handle negative dentries in case insensitive filesystem
  * Fix casesensitivity=insensitive deadlock
  * Correctly parse zdb -R flag arguments
  * Fix lock order inversion with zvol_open()
  * Add support for asynchronous zvol minor operations
  * Make zvol minor functionality more robust
  * Prevent zpool_find_vdev() from truncating vdev path
  * Add -gLP to zpool subcommands for alt vdev names
  * Fix zpool list -v output for spares and log devices
  * Fix ZFS send fails to transmit some holes
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 0.6.5.5
  * Support for Linux 4.5
  * Make arc_summary.py and dbufstat.py compatible with python3
  * Prevent arc_c collapse and possible panic
  * Prevent duplicated xattr between SA and dir
  * Fix zsb->z_hold_mtx deadlock
  * Prevent SA header corruption
  * Fix potential deadlock in cv_wait()
  * Fix livelock in shrinker
* Sun Jan 17 2016 dev@stellardeath.org
- Update to release 0.6.5.4
* Wed Dec  9 2015 yury.buldakov@gmail.com
- Update to release 0.6.5.3
* Sun Oct 11 2015 dev@stellardeath.org
- Update to release 0.6.5.2
* Fri Jul 17 2015 jengelh@inai.de
- Update to new upstream release 0.6.4.2
  * No changelog was provided
* Thu Jul 17 2014 jengelh@inai.de
- Update to new upstream release 0.6.3
  * New features added: I/O read/write accounting, file attributes,
  POSIX ACLs, SELinux support, "relatime" mount option
  * systemd service integration
  * The ZFS Event Daemon was added
  * `zpool create` treats -O mountpoint and -m the same
  * `zpool create -o altroot=/xyz -O mountpoint=/mnt` recognizes
  the mountpoint option now
  * `zpool get` and `zpool list` now recognize the -p option
  * `zfs recv -F` destroys any snapshots created since the
  incremental source
  * `zfs send -D` works again
  * `zpool import` gained the -t option for temporary pool names
  * `zpool import` lost the unused -r option
  * Fix panic on `zfs receive` of a recursive deduplicated stream
  * `zfs hold` or `zfs release` of a non-existent snapshot did not
  output an error
  * ZFS quota or reservation on pool version < 22 can be set again
  * Improved ZFS send / receive performance due to snapshot
  hold / release processing
  * `zpool status -x` reports pools with removed L2ARC devices
  * zfs rejects snapshots of inconsistent datasets
* Sat Aug 31 2013 jengelh@inai.de
- Update to new upstream release 0.6.2
  * Added Linux 3.11 compatibility
  * Added arcstat.py script from FreeNAS
  * Added 'zpool labelclear' command from FreeBSD
  * Added L2ARC compression from Illumos
  * Added I/O deadman thread from Illumos
  * Added SEEK_DATA/SEEK_HOLE to lseek()/llseek()
  * Added writeable arc+l2arc module options
  * Improved detection of advanced format (AF) disks
  * Improved N-way mirror read performance
  * Improved zdb to display SA xattrs
* Sat Mar 30 2013 jengelh@inai.de
- Initial package (version 0.6.1) for build.opensuse.org
